API
###

HGSig
=====
.. module:: hgsig
.. currentmodule:: hgsig
.. autosummary::
    :toctree: generated/

    HGSig

Plotting
========
.. module:: hgsig
.. currentmodule:: hgsig
.. autosummary::
    :toctree: generated/

    plot_hgsig
